@@ -36,24 +36,12 @@ function _initializerDefineProperty(target, property, descriptor, context) {
         value: descriptor.initializer ? descriptor.initializer.call(context) : void 0
     });
 }
-var _class, _descriptor, _descriptor1, _descriptor2, _descriptor3, _descriptor4, _descriptor5, _descriptor6, _descriptor7;
-var _dec = ViewColumn({
-    name: "tmcode"
-}), _dec1 = ViewColumn({
-    name: "mid"
-}), _dec2 = ViewColumn({
-    name: "accea"
-}), _dec3 = ViewColumn({
-    name: "qaccea"
-}), _dec4 = ViewColumn({
-    name: "endday"
-}), _dec5 = ViewColumn({
-    name: "quick_endday"
-}), _dec6 = ViewColumn(), _dec7 = ViewColumn(), _dec8 = ViewEntity({
+var _class, _descriptor, _dec, _dec1, _descriptor1, _dec2, _dec3, _descriptor2, _dec4, _dec5, _descriptor3, _dec6, _dec7, _descriptor4, _dec8, _dec9, _descriptor5, _dec10, _dec11, _descriptor6, _dec12, _dec13, _descriptor7, _dec14, _dec15;
+var _dec16 = ViewEntity({
     name: "AccountMemberView",
     expression: "\n    SELECT\n        m.tmcode, m.mid, m.accea, m.qaccea, m.endday, m.quick_endday,\n        (SELECT COUNT(*) FROM TBLACCOUNT a WHERE m.mid = a.mid AND a.use_quick=\"F\") as accountCnt,\n        (SELECT COUNT(*) FROM TBLACCOUNT a WHERE m.mid = a.mid AND a.use_quick=\"T\") as accountQuickCnt\n    FROM TBLMEMBER m\n    "
 });
-export var AccountMemberView = _class = _dec8((_class = function AccountMemberView1() {
+export var AccountMemberView = _class = _dec16((_class = function AccountMemberView1() {
     "use strict";
     _classCallCheck(this, AccountMemberView1);
     _initializerDefineProperty(this, "memberId", _descriptor, this);
@@ -64,65 +52,77 @@ export var AccountMemberView = _class = _dec8((_class = function AccountMemberVi
     _initializerDefineProperty(this, "accountQuickEnddedAt", _descriptor5, this);
     _initializerDefineProperty(this, "accountCnt", _descriptor6, this);
     _initializerDefineProperty(this, "accountQuickCnt", _descriptor7, this);
-}, _descriptor = _applyDecoratedDescriptor(_class.prototype, "memberId", [
+}, _dec = ViewColumn({
+    name: "tmcode"
+}), _dec1 = typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number), _dec2 = ViewColumn({
+    name: "mid"
+}), _dec3 = typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", String), _dec4 = ViewColumn({
+    name: "accea"
+}), _dec5 = typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number), _dec6 = ViewColumn({
+    name: "qaccea"
+}), _dec7 = typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number), _dec8 = ViewColumn({
+    name: "endday"
+}), _dec9 = typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", typeof Date === "undefined" ? Object : Date), _dec10 = ViewColumn({
+    name: "quick_endday"
+}), _dec11 = typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", typeof Date === "undefined" ? Object : Date), _dec12 = ViewColumn(), _dec13 = typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number), _dec14 = ViewColumn(), _dec15 = typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number), _descriptor = _applyDecoratedDescriptor(_class.prototype, "memberId", [
     _dec,
-    typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number)
+    _dec1
 ], {
     configurable: true,
     enumerable: true,
     writable: true,
     initializer: void 0
 }), _descriptor1 = _applyDecoratedDescriptor(_class.prototype, "mallId", [
-    _dec1,
-    typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", String)
+    _dec2,
+    _dec3
 ], {
     configurable: true,
     enumerable: true,
     writable: true,
     initializer: void 0
 }), _descriptor2 = _applyDecoratedDescriptor(_class.prototype, "allowAccountCnt", [
-    _dec2,
-    typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number)
+    _dec4,
+    _dec5
 ], {
     configurable: true,
     enumerable: true,
     writable: true,
     initializer: void 0
 }), _descriptor3 = _applyDecoratedDescriptor(_class.prototype, "allowQuickAccountCnt", [
-    _dec3,
-    typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number)
+    _dec6,
+    _dec7
 ], {
     configurable: true,
     enumerable: true,
     writable: true,
     initializer: void 0
 }), _descriptor4 = _applyDecoratedDescriptor(_class.prototype, "accountEnddedAt", [
-    _dec4,
-    typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", typeof Date === "undefined" ? Object : Date)
+    _dec8,
+    _dec9
 ], {
     configurable: true,
     enumerable: true,
     writable: true,
     initializer: void 0
 }), _descriptor5 = _applyDecoratedDescriptor(_class.prototype, "accountQuickEnddedAt", [
-    _dec5,
-    typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", typeof Date === "undefined" ? Object : Date)
+    _dec10,
+    _dec11
 ], {
     configurable: true,
     enumerable: true,
     writable: true,
     initializer: void 0
 }), _descriptor6 = _applyDecoratedDescriptor(_class.prototype, "accountCnt", [
-    _dec6,
-    typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number)
+    _dec12,
+    _dec13
 ], {
     configurable: true,
     enumerable: true,
     writable: true,
     initializer: void 0
 }), _descriptor7 = _applyDecoratedDescriptor(_class.prototype, "accountQuickCnt", [
-    _dec7,
-    typeof Reflect !== "undefined" && typeof Reflect.metadata === "function" && Reflect.metadata("design:type", Number)
+    _dec14,
+    _dec15
 ], {
     configurable: true,
     enumerable: true,
