@@ -651,10 +651,10 @@ fn deno_10282_2() {
     .unwrap();
     println!("{}", output);
 
-    assert_eq!(output.to_string(), "const a = `\\n`;\n");
+    assert_eq!(output.to_string(), "const a = `\n`;\n");
 }
 
-#[testing::fixture("fixture/**/input/")]
+#[testing::fixture("tests/fixture/**/input/")]
 fn tests(dir: PathBuf) {
     let output = dir.parent().unwrap().join("output");
     let _ = create_dir_all(&output);
